==> wildfly-clustering-spring-session-3.0.3.Final-source-release.zip: wildfly-clustering-spring-session-3.0.3.Final/hotrod/src/test/java/org/wildfly/clustering/web/spring/hotrod/auth/Config.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2020, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.wildfly.clustering.web.spring.hotrod.auth;

import org.wildfly.clustering.web.spring.SessionMarshallerFactory;
import org.wildfly.clustering.web.spring.SessionPersistenceGranularity;
import org.wildfly.clustering.web.spring.annotation.Indexing;
import org.wildfly.clustering.web.spring.annotation.SessionManager;
import org.wildfly.clustering.web.spring.hotrod.annotation.EnableHotRodIndexedHttpSession;
import org.wildfly.clustering.web.spring.hotrod.annotation.HotRod;

/**
 * Test configuration for session manager.
 * @author Paul Ferraro
 */
@EnableHotRodIndexedHttpSession(config = @HotRod(uri = "hotrod://127.0.0.1:11222", template = "default"), manager = @SessionManager(marshallerFactory = SessionMarshallerFactory.JBOSS, granularity = SessionPersistenceGranularity.ATTRIBUTE), indexing = @Indexing)
public class Config {

}

==> wildfly-clustering-spring-session-9.0.0.Final-source-release.zip: wildfly-clustering-spring-session-9.0.0.Final/hotrod/src/test/java/org/wildfly/clustering/web/spring/hotrod/auth/Config.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2020, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.wildfly.clustering.web.spring.hotrod.auth;

import org.wildfly.clustering.web.spring.SessionMarshallerFactory;
import org.wildfly.clustering.web.spring.SessionPersistenceGranularity;
import org.wildfly.clustering.web.spring.annotation.Indexing;
import org.wildfly.clustering.web.spring.annotation.SessionManager;
import org.wildfly.clustering.web.spring.hotrod.annotation.EnableHotRodIndexedHttpSession;
import org.wildfly.clustering.web.spring.hotrod.annotation.HotRod;

/**
 * Test configuration for session manager.
 * @author Paul Ferraro
 */
@EnableHotRodIndexedHttpSession(config = @HotRod(uri = "hotrod://testsuite-application-user:testsuite-application-password@127.0.0.1:11222?tcp_no_delay=true", template = "default"), manager = @SessionManager(marshallerFactory = SessionMarshallerFactory.JBOSS, granularity = SessionPersistenceGranularity.ATTRIBUTE), indexing = @Indexing)
public class Config {

}
